pub struct FilePart {
pub file_with_bytes: Option<FilePartFileWithBytes>,
pub file_with_uri: Option<String>,
pub media_type: String,
pub name: String,
}Expand description
FilePart represents the different ways files can be provided. If files are small, directly feeding the bytes is supported via file_with_bytes. If the file is large, the agent should read the content as appropriate directly from the file_with_uri source.
JSON schema
{
"title": "File Part",
"description": "FilePart represents the different ways files can be provided. If files are\n small, directly feeding the bytes is supported via file_with_bytes. If the\n file is large, the agent should read the content as appropriate directly\n from the file_with_uri source.",
"type": "object",
"required": [
"mediaType",
"name"
],
"properties": {
"fileWithBytes": {
"description": "The base64-encoded content of the file.",
"type": "string",
"pattern": "^[A-Za-z0-9+/]*={0,2}$"
},
"fileWithUri": {
"description": "A URL pointing to the file's content.",
"type": "string"
},
"mediaType": {
"description": "The media type of the file (e.g., \"application/pdf\").",
"type": "string"
},
"name": {
"description": "An optional name for the file (e.g., \"document.pdf\").",
"type": "string"
}
},
"additionalProperties": false,
"$schema": "https://json-schema.org/draft/2020-12/schema"
}Fields
file_with_bytes: Option<FilePartFileWithBytes>The base64-encoded content of the file.
file_with_uri: Option<String>A URL pointing to the file’s content.
media_type: StringThe media type of the file (e.g., “application/pdf”).
name: StringAn optional name for the file (e.g., “document.pdf”).
Implementations