pub struct GetTaskRequest {
pub history_length: Option<i32>,
pub name: String,
pub tenant: Option<String>,
}Expand description
Represents a request for the tasks/get method.
JSON schema
{
"title": "Get Task Request",
"description": "Represents a request for the `tasks/get` method.",
"type": "object",
"required": [
"name"
],
"properties": {
"historyLength": {
"description": "The maximum number of messages to include in the history.",
"type": "integer",
"maximum": 2147483647.0,
"minimum": -2147483648.0
},
"name": {
"description": "The resource name of the task.\n Format: tasks/{task_id}",
"type": "string"
},
"tenant": {
"description": "Optional tenant, provided as a path parameter.",
"type": "string"
}
},
"additionalProperties": false,
"$schema": "https://json-schema.org/draft/2020-12/schema"
}Fields
history_length: Option<i32>The maximum number of messages to include in the history.
name: StringThe resource name of the task. Format: tasks/{task_id}
tenant: Option<String>Optional tenant, provided as a path parameter.
Implementations
Sourceimpl GetTaskRequest
impl GetTaskRequest
pub fn builder() -> GetTaskRequest