pub struct SubscribeToTaskRequest {
pub name: String,
pub tenant: String,
}Expand description
SubscribeToTaskRequest
JSON schema
{
"title": "Subscribe To Task Request",
"type": "object",
"required": [
"name",
"tenant"
],
"properties": {
"name": {
"description": "The resource name of the task to subscribe to.\n Format: tasks/{task_id}",
"type": "string"
},
"tenant": {
"description": "Optional tenant, provided as a path parameter.",
"type": "string"
}
},
"additionalProperties": false,
"$schema": "https://json-schema.org/draft/2020-12/schema"
}Fields
name: StringThe resource name of the task to subscribe to. Format: tasks/{task_id}
tenant: StringOptional tenant, provided as a path parameter.
Implementations
Sourceimpl SubscribeToTaskRequest
impl SubscribeToTaskRequest
pub fn builder() -> SubscribeToTaskRequest