pub struct TaskPushNotificationConfig {
pub name: String,
pub push_notification_config: PushNotificationConfig,
}Expand description
A container associating a push notification configuration with a specific task.
JSON schema
{
"title": "Task Push Notification Config",
"description": "A container associating a push notification configuration with a specific\n task.",
"type": "object",
"required": [
"name",
"pushNotificationConfig"
],
"properties": {
"name": {
"description": "The resource name of the config.\n Format: tasks/{task_id}/pushNotificationConfigs/{config_id}",
"type": "string"
},
"pushNotificationConfig": {
"description": "The push notification configuration details.",
"$ref": "#/definitions/PushNotificationConfig"
}
},
"additionalProperties": false,
"$schema": "https://json-schema.org/draft/2020-12/schema"
}Fields
name: StringThe resource name of the config. Format: tasks/{task_id}/pushNotificationConfigs/{config_id}
push_notification_config: PushNotificationConfigThe push notification configuration details.
Implementations
Sourceimpl TaskPushNotificationConfig
impl TaskPushNotificationConfig
pub fn builder() -> TaskPushNotificationConfig