pub struct TaskStatusUpdateEvent {
pub context_id: String,
pub final_: bool,
pub metadata: Option<Struct>,
pub status: TaskStatus,
pub task_id: String,
}Expand description
An event sent by the agent to notify the client of a change in a task’s status.
JSON schema
{
"title": "Task Status Update Event",
"description": "An event sent by the agent to notify the client of a change in a task's\n status.",
"type": "object",
"required": [
"contextId",
"final",
"status",
"taskId"
],
"properties": {
"contextId": {
"description": "The id of the context that the task belongs to",
"type": "string"
},
"final": {
"description": "If true, this is the final event in the stream for this interaction.",
"type": "boolean"
},
"metadata": {
"description": "Optional metadata to associate with the task update.",
"$ref": "#/definitions/Struct"
},
"status": {
"description": "The new status of the task.",
"$ref": "#/definitions/TaskStatus"
},
"taskId": {
"description": "The id of the task that is changed",
"type": "string"
}
},
"additionalProperties": false,
"$schema": "https://json-schema.org/draft/2020-12/schema"
}Fields
context_id: StringThe id of the context that the task belongs to
final_: boolIf true, this is the final event in the stream for this interaction.
metadata: Option<Struct>Optional metadata to associate with the task update.
status: TaskStatusThe new status of the task.
task_id: StringThe id of the task that is changed
Implementations
Sourceimpl TaskStatusUpdateEvent
impl TaskStatusUpdateEvent
pub fn builder() -> TaskStatusUpdateEvent